import { CloverAction } from "gap-nodejs-sdk/dist/clover/enums";
import { PaymentResponseModel } from "gap-nodejs-sdk/dist/clover/payment_response_model";
export class CloverUsbPaymentResponseModel extends PaymentResponseModel {
    static build(data) {
        console.log(data);
        let paymentResponse = new PaymentResponseModel();
        if (data.Success) {
            paymentResponse.status = PaymentResponseModel.STATUS_OK;
            paymentResponse.statusCode = PaymentResponseModel.STATUS_CODE_OK;
        }
        else {
            paymentResponse.status = PaymentResponseModel.STATUS_FAIL;
            paymentResponse.statusCode = PaymentResponseModel.STATUS_CODE_FAIL;
        }
        paymentResponse.statusMessage = data.Message;
        paymentResponse.data = data.Payment ? CloverUsbPaymentResponseModel.mapPaymentData(data.Payment || null) : CloverUsbPaymentResponseModel.mapResponseData(data);
        switch (data.type) {
            case 'sale':
                paymentResponse.action = CloverAction.ACTION_CLOVER_SALE_RESPONSE;
                if (data.Payment && data.Payment.result == "SUCCESS") {
                    paymentResponse.refID = data.Payment.id;
                    paymentResponse.approveAmount = data.Payment.amount;
                }
                else {
                    paymentResponse.status = PaymentResponseModel.STATUS_FAIL;
                    paymentResponse.statusCode = PaymentResponseModel.STATUS_CODE_FAIL;
                }
                break;
            case 'auth':
                paymentResponse.action = CloverAction.ACTION_CLOVER_AUTH_RESPONSE;
                if (data.Payment && data.Payment.result == "SUCCESS") {
                    paymentResponse.refID = data.Payment.id;
                    paymentResponse.approveAmount = data.Payment.amount;
                }
                else {
                    paymentResponse.status = PaymentResponseModel.STATUS_FAIL;
                    paymentResponse.statusCode = PaymentResponseModel.STATUS_CODE_FAIL;
                }
                break;
            case 'adjust':
                paymentResponse.action = CloverAction.ACTION_CLOVER_ADJUST_RESPONSE;
                if (data.Payment) {
                    paymentResponse.refID = data.Payment.id;
                }
                break;
            case 'void':
                paymentResponse.action = CloverAction.ACTION_CLOVER_VOID_RESPONSE;
                if (data.Reason == "REJECT_PARTIAL_AUTH") {
                    paymentResponse.action = CloverAction.ACTION_CLOVER_CANCEL_TRANSACTION_WITH_DUE_AMOUNT;
                }
                if (data.Payment) {
                    paymentResponse.refID = data.Payment.id;
                }
                break;
            case 'refund':
                paymentResponse.action = CloverAction.ACTION_CLOVER_RETURN_RESPONSE;
                if (data.Payment) {
                    paymentResponse.refID = data.Payment.id;
                }
                break;
            case 'batch_close':
                paymentResponse.action = CloverAction.ACTION_CLOVER_BATCH_CLOSE_RESPONSE;
                paymentResponse.data = data.Batch || null;
                break;
            case 'retrieve':
                paymentResponse.action = CloverAction.ACTION_CLOVER_RETRIEVE_RESPONSE;
                if (data.Payment && data.Payment.result == "SUCCESS") {
                    paymentResponse.refID = data.Payment.id;
                }
                else {
                    paymentResponse.status = PaymentResponseModel.STATUS_FAIL;
                    paymentResponse.statusCode = PaymentResponseModel.STATUS_CODE_FAIL;
                }
                break;
        }
        return paymentResponse;
    }
    static mapPaymentData(paymentData) {
        if (paymentData == null) {
            return null;
        }
        paymentData.result = CloverUsbPaymentResponseModel.PaymentResult[paymentData.result];
        if (paymentData.cardTransaction != null) {
            paymentData.cardTransaction.cardType = CloverUsbPaymentResponseModel.PaymentCardType[paymentData.cardTransaction.cardType];
            paymentData.cardTransaction.entryType = CloverUsbPaymentResponseModel.PaymentCardEntryType[paymentData.cardTransaction.entryType];
            paymentData.cardTransaction.type = CloverUsbPaymentResponseModel.PaymentCardTransactionType[paymentData.cardTransaction.type];
            paymentData.cardTransaction.state = CloverUsbPaymentResponseModel.PaymentCardTransactionState[paymentData.cardTransaction.state];
        }
        return paymentData;
    }
    static mapResponseData(responseData) {
        let response = {};
        if (responseData == null) {
            return null;
        }
        Object.keys(responseData).forEach((key) => {
            if (key) {
                response[key.charAt(0).toLowerCase() + key.slice(1)] = responseData[key];
            }
        });
        response["type"] = responseData.type;
        response["result"] = CloverUsbPaymentResponseModel.ResponseCode[responseData.Result];
        return response;
    }
}
CloverUsbPaymentResponseModel.PaymentResult = [
    "SUCCESS",
    "FAIL",
    "INITIATED",
    "VOIDED",
    "VOIDING",
    "AUTH",
    "AUTH_COMPLETED"
];
CloverUsbPaymentResponseModel.ResponseCode = [
    "SUCCESS",
    "FAIL",
    "UNSUPPORTED",
    "CANCEL",
    "ERROR"
];
CloverUsbPaymentResponseModel.PaymentCardType = [
    "VISA",
    "MC",
    "AMEX",
    "DISCOVER",
    "DINERS_CLUB",
    "JCB",
    "MAESTRO",
    "SOLO",
    "LASER",
    "CHINA_UNION_PAY",
    "CARTE_BLANCHE",
    "UNKNOWN",
    "GIFT_CARD",
    "EBT",
    "INTERAC",
    "OTHER"
];
CloverUsbPaymentResponseModel.PaymentCardEntryType = [
    "SWIPED",
    "KEYED",
    "VOICE",
    "VAULTED",
    "OFFLINE_SWIPED",
    "OFFLINE_KEYED",
    "EMV_CONTACT",
    "EMV_CONTACTLESS",
    "MSD_CONTACTLESS",
    "PINPAD_MANUAL_ENTRY"
];
CloverUsbPaymentResponseModel.PaymentCardTransactionType = [
    "AUTH",
    "PREAUTH",
    "PREAUTHCAPTURE",
    "ADJUST",
    "VOID",
    "VOIDRETURN",
    "RETURN",
    "REFUND",
    "NAKEDREFUND",
    "GETBALANCE",
    "BATCHCLOSE",
    "ACTIVATE",
    "BALANCE_LOCK",
    "LOAD",
    "CASHOUT",
    "CASHOUT_ACTIVE_STATUS",
    "REDEMPTION",
    "REDEMPTION_UNLOCK",
    "RELOAD"
];
CloverUsbPaymentResponseModel.PaymentCardTransactionState = ["PENDING", "CLOSED"];
